=====
Usage
=====

To use Hangar in a project::

	from hangar import Repository


Please refer to the :ref:`ref-tutorial` for examples, or :ref:`ref-concepts` to
review the core concepts of the Hangar system.